import 'dart:async';

import 'package:flutter/services.dart';

class XinlakePlatform {
  static const MethodChannel _channel = MethodChannel('xinlake_platform');

  /// * [isMultiSelection]: Multiple selection
  /// ***
  /// Android
  /// * [mimeType]: Acceptable MIME types such as "image/jpeg", "audio/*"
  /// ***
  /// Windows
  /// * [openPath]: Path to open
  /// * [defaultPath]: Default open folder for the dialog, if [openPath] is set
  /// then this will be ignored.
  /// * [filterName]: Friendly name of the filter
  /// * [filterPattern]: Filter pattern
  static Future<List<String>?> pickFiles({
    bool isMultiSelection = false,
    // android
    String mimeType = "*/*",
    // windows
    String openPath = "",
    String defaultPath = "",
    required String filterName,
    required String filterPattern,
  }) async {
    try {
      return await _channel.invokeListMethod('pickFiles', {
        "isMultiSelection": isMultiSelection,
        "mimeType": mimeType,
        "openPath": openPath,
        "defaultPath": defaultPath,
        "filterName": filterName,
        "filterPattern": filterPattern,
      });
    } catch (error) {
      return null;
    }
  }

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}
